| StatModel | R Documentation |
StatModel passes through rows prepared from a supplied model. With no
supplied model, it fits the model implied by the mapped positions: a linear
model for a continuous predictor, group means for a categorical predictor,
or an intercept when only the outcome is mapped.
StatModel
StatModel is a ggplot2::Stat object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.