| estimate_extraction | R Documentation |
This collection of functions is useful for extracting estimates and statistics from a fitted
model. They are particularly useful when estimating many models, like when bootstrapping
confidence intervals. Each function can be used with an already fitted model as an lm object,
or a formula and associated data can be passed to it. All of these assume the comparison is the
empty model.
b0(object, data = NULL)
b1(object, data = NULL)
b(object, data = NULL, all = FALSE, predictor = character())
f(object, data = NULL, all = FALSE, predictor = character(), type = 3)
pre(object, data = NULL, all = FALSE, predictor = character(), type = 3)
p(object, data = NULL, all = FALSE, predictor = character(), type = 3)
object |
A |
data |
If |
all |
If |
predictor |
Filter the output down to just the statistics for these terms (e.g. "hp" to
just get the statistics for that term in the model). This argument is flexible: you can pass
a character vector of terms ( |
type |
The type of sums of squares to calculate (see |
b0: The intercept from the full model.
b1: The slope b1 from the full model.
b: The coefficients from the full model.
f: The F value from the full model.
pre: The Proportional Reduction in Error for the full model.
p: The p-value from the full model.
sse: The SS Error (SS Residual) from the model.
ssm: The SS Model (SS Regression) for the full model.
ssr: Alias for SSM.
fVal() and PRE() are older names for f() and pre(). They are kept
for backward compatibility and behave identically to the newer functions.
The value of the estimate as a single number.
Judd, C. M., McClelland, G. H., & Ryan, C. S. (2017). Data Analysis: A Model Comparison Approach to Regression, ANOVA, and Beyond (3rd ed.). New York: Routledge. ISBN:879-1138819832
supernova(lm(mpg ~ disp, data = mtcars))
change_p_decimals <- supernova(lm(mpg ~ disp, data = mtcars))
print(change_p_decimals, pcut = 8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.