| guide_dgp | R Documentation |
guide_dgp() places a truthful null anchor in measured guide space. The
population role supplies the population heading, equation, axis line, null
label, and triangle. The estimate role supplies the estimate heading,
equation, and null label. It never computes a mean or trains a scale.
guide_dgp(
value = 0,
role = c("population", "estimate"),
label = ggplot2::waiver(),
equation = ggplot2::waiver(),
colour = ggplot2::waiver(),
shape = ggplot2::waiver(),
size = ggplot2::waiver(),
linewidth = ggplot2::waiver(),
title = ggplot2::waiver(),
theme = NULL,
order = 0,
position = ggplot2::waiver()
)
GuideDgp
value |
One finite numeric null value in the position scale's data space. |
role |
Either |
label |
The null label. A role-specific plotmath label is used by default. |
equation |
The model equation. A role-specific plotmath expression is used by default. |
colour |
Colour of the keyed null content. |
shape |
Point shape for the population marker. The default points toward the panel. |
size |
Size of the population marker. |
linewidth |
Width of the population axis line. |
title |
The role heading. A role-specific heading is used by default. |
theme |
A theme for this guide, or |
order |
Guide order. |
position |
Guide position. The default is derived from the scale. |
GuideDgp is a ggplot2::Guide object.
A ggplot2 guide.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.