View source: R/gf_square_resid_fun.R
| gf_square_resid_fun | R Documentation |
gf_square_resid_fun(plot, fun, aspect = 4/6, alpha = 0.1, ...)
plot |
A ggformula/ggplot object, typically created with |
fun |
A function that takes a numeric vector x and returns predicted y. |
aspect |
A numeric value controlling the square's aspect ratio.
Default is |
alpha |
Transparency of the filled squares. Default |
... |
Additional aesthetics passed to |
Draws squared residual polygons between observed points and predicted values computed by a user-supplied function of x.
A ggplot object with squared residual polygons added.
set.seed(1)
df <- data.frame(X = 1:10, Y = 2 + 3 * (1:10) + rnorm(10))
my_fun <- function(x) 2 + 3 * x
gf_point(Y ~ X, data = df) %>%
gf_function(my_fun) %>%
gf_square_resid_fun(my_fun, color = "red", alpha = 0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.