| show_cutoffs | R Documentation |
show_cutoffs(plot, color = "#1e3a8a", size = 4, labels = FALSE)
plot |
A ggplot histogram with |
color |
Marker/line color. Default |
size |
Marker size. Default |
labels |
Whether to add text annotations explaining the cutoffs.
Default |
Adds downward-pointing triangle markers at the empirical quantile cutoffs on
a histogram that uses a distribution part function (middle(), tails(),
upper(), lower(), or outer()) in its fill aesthetic.
A ggplot object with cutoff markers and optional labels.
gf_histogram(~Thumb, data = Fingers, fill = ~middle(Thumb, .95)) %>%
show_cutoffs(labels = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.